import Vue from 'vue';
import VueRouter from 'vue-router';
import store from '@/store/index';
import { Notification } from 'element-ui';

Vue.use(VueRouter);

const routes = [
  {
    path: '/',
    name: 'frame',
    component: () => import('@/views/index.vue'),
    children: [
      {
        path: '/',
        name: 'home',
        component: () => import('@/views/home/index.vue'),
      },
      {
        path: '/info',
        name: 'teacherInfo_index',
        meta: { title: '教师信息', sub: '管理' },
        component: () => import('@/views/teacherInfo/index.vue'),
      },
      {
        path: '/newPlan/index',
        name: 'plan_list',
        meta: { title: '计划', sub: '列表' },
        component: () => import('@/views/plan/index.vue'),
      },
      {
        path: '/plan/detail',
        name: 'plan_detail',
        meta: { title: '计划', sub: '详情' },
        component: () => import('@/views/plan/detail.vue'),
      },
      {
        path: '/plan/classes',
        name: 'plan_classes',
        meta: { title: '授课班级' },
        component: () => import('@/views/plan/classes.vue'),
      },
      {
        path: '/plan/name/list',
        name: 'plan_name_list',
        meta: { title: '授课班级' },
        component: () => import('@/views/plan/classes/name-list.vue'),
      },
      {
        path: '/plan/class/info',
        name: 'plan_class_info',
        meta: { title: '班级信息' },
        component: () => import('@/views/plan/classes/info.vue'),
      },
      {
        path: '/train/plan/term/lesson',
        name: 'lesson_index',
        meta: { title: '课程信息' },
        component: () => import('@/views/lesson/index.vue'),
      },
      {
        path: '/task/index',
        name: 'task_index',
        meta: { title: '作业管理' },
        component: () => import('@/views/task/index.vue'),
      },
      {
        path: '/task/taskList',
        name: 'task_taskList',
        meta: { title: '学生作业列表' },
        component: () => import('@/views/task/taskList.vue'),
      },
      {
        path: '/task/taskDetail',
        name: 'task_taskDetail',
        meta: { title: '学生作业详情' },
        component: () => import('@/views/task/taskDetail.vue'),
      },
      {
        path: '/class/index',
        name: 'class_index',
        meta: { title: '班级信息' },
        component: () => import('@/views/class/index.vue'),
      },
      {
        path: '/student/index',
        name: 'class_classStuList',
        meta: { title: '学生名单' },
        component: () => import('@/views/class/classStuList.vue'),
      },
      // 在线授课
      {
        path: '/centerTeaching/index',
        name: 'teaching_index',
        meta: { title: '直播讲课' },
        component: () => import('@/views/teaching/index.vue'),
      },
      {
        path: '/teaching/detail',
        name: 'teaching_detail',
        meta: { title: '直播讲课信息', sub: '管理' },
        component: () => import('@/views/teaching/detail.vue'),
      },
      {
        path: '/teaching/live',
        name: 'teaching_live',
        meta: { title: '直播讲课', sub: '管理' },
        component: () => import('@/views/teaching/live.vue'),
      },
      {
        path: '/centerTeaching/afterClass',
        name: 'teaching_afterClass',
        meta: { title: '课后答疑', sub: '管理' },
        component: () => import('@/views/teaching/afterClass.vue'),
      },
      {
        path: '/teaching/afterClassDetail',
        name: 'teaching_afterClassDetail',
        meta: { title: '课后答疑', sub: '管理' },
        component: () => import('@/views/teaching/afterClassDetail.vue'),
      },
      {
        path: '/teaching/list',
        name: 'teaching_afterClassList',
        meta: { title: '答疑列表', sub: '管理' },
        component: () => import('@/views/teaching/afterClassList.vue'),
      },
      {
        path: '/teaching/afterClassChat',
        name: 'teaching_afterClassChat',
        meta: { title: '答疑聊天', sub: '管理' },
        component: () => import('@/views/teaching/afterClassChat.vue'),
      },

      {
        path: '/trainVidoe/index',
        name: 'trainVidoe_index',
        meta: { title: '课程培训', sub: '管理' },
        component: () => import('@/views/trainVidoe/index.vue'),
      },
      {
        path: '/trainVidoe/detail',
        name: 'trainVidoe_detail',
        meta: { title: '课程培训', sub: '管理' },
        component: () => import('@/views/trainVidoe/detail.vue'),
      },
      {
        path: '/trainVidoe/viewVideo',
        name: 'trainVidoe_viewVideo',
        meta: { title: '课程培训', sub: '管理' },
        component: () => import('@/views/trainVidoe/viewVideo.vue'),
      },
      // 积分榜
      {
        path: '/league/index',
        name: 'league_index',
        meta: { title: '积分榜', sub: '管理' },
        component: () => import('@/views/league/index.vue'),
      },
      {
        path: '/live/look',
        name: 'live_look',
        meta: { title: '看直播', sub: '' },
        component: () => import('@/views/teaching/livelook.vue'),
      },
    ],
  },
  {
    path: '/login',
    name: 'login',
    meta: { title: '登录', sub: '管理' },
    component: () => import('@/views/register/login.vue'),
  },
];

const router = new VueRouter({
  mode: 'history',
  base: process.env.NODE_ENV === 'development' ? '' : 'teacher',
  routes,
});
router.beforeEach((to, form, next) => {
  store.commit('setUser');
  store.dispatch('setting/checkCache');
  if (to.name === 'login') {
    next();
    return;
  }
  let user = store.state.user;
  if (user) {
    if (user.type == process.env.VUE_APP_USER_TYPE) {
      console.log('已登录');
      next();
    } else {
      Notification({
        title: '请重新登陆',
        message: `原因:非当前端用户,需要重新登陆`,
        type: 'warning',
      });
      console.warn('非当前端用户,需要重新登陆');
      next({ name: 'login' });
    }
  }
  //下面是没登录的情况,需要跳转页面到用户未登录页
  else next({ name: 'login' });
});

export default router;
